@@ -1,27 +1,31 @@
-# -*- encoding: utf-8 -*-
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    GNU Health: The Free Health and Hospital Information System
+#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, either version 3 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
 {
-
     'name': 'GNU Health : Free Health and Hospital Information System',
-    'version': '1.4.4',
+    'name_es_ES': 'GNU Health : Sistema Libre de Gestión Hospitalaria y de Salud',
+    'version': '1.4.5',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
-    'website': "http://health.gnu.org",
-    'depends': ['ir', 'res', 'product', 'party', 'company'],
-    'name_es_ES': 'GNU Health : Sistema Libre de Gestión Hospitalaria y de Salud',
-    'translation': ['locale/es_ES.po', 'locale/fr_FR.po', 'locale/el.po',
-        'locale/fa.po','locale/it.po'],
-    
-
-    "xml": ["health_view.xml", "data/medicament_categories.xml",
-        "data/health_product.xml", "data/WHO_products.xml",
-        "data/WHO_list_of_essential_medicines.xml",
-        "data/health_specialties.xml", "data/ethnic_groups.xml",
-        "data/occupations.xml", "data/dose_units.xml",
-        "data/drug_administration_routes.xml", "data/medicament_form.xml",
-        "data/medication_frequencies.xml", "data/health_sequences.xml",
-        "security/access_rights.xml", "health_report.xml"],
-
-    'description': """
+    'website': 'http://health.gnu.org',
+    'description': '''
 
 About GNU Health
 ----------------------
@@ -66,9 +70,9 @@ GNU Health at a glance:
 
 Please check the main project at the GNU Savannah (http://savannah.gnu.org/projects/health ) for the latest news and developer releases.
 
-""",
-
+''',
     'description_es_ES': '''
+
 Acerca de GNU Health
 ---------------------------------
 
@@ -123,6 +127,35 @@ Características de GNU Health :
 ** Puede escribirnos a health@gnusolidario.org
 
 ''',
-
-
+    'depends': [
+        'ir',
+        'res',
+        'product',
+        'party',
+        'company',
+    ],
+    'xml': [
+        'health_view.xml',
+        'data/medicament_categories.xml',
+        'data/health_product.xml',
+        'data/WHO_products.xml',
+        'data/WHO_list_of_essential_medicines.xml',
+        'data/health_specialties.xml',
+        'data/ethnic_groups.xml',
+        'data/occupations.xml',
+        'data/dose_units.xml',
+        'data/drug_administration_routes.xml',
+        'data/medicament_form.xml',
+        'data/medication_frequencies.xml',
+        'data/health_sequences.xml',
+        'security/access_rights.xml',
+        'health_report.xml',
+    ],
+    'translation': [
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/el.po',
+        'locale/fa.po',
+        'locale/it.po',
+    ],
 }
