@@ -1,32 +1,27 @@
-# coding=utf-8
-
-#    Copyright (C) 2008-2012  Luis Falcon
-
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    GNU Health: The Free Health and Hospital Information System
+#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-
+#
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
-
+#
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
 
-import time
-import logging
-
-from dateutil.relativedelta import relativedelta
-from datetime import datetime
 
 from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
-from trytond.tools import safe_eval, datetime_strftime
 from trytond.transaction import Transaction
-from trytond.pyson import Eval, Not, Equal, If, In, Bool, Get, Or, And, \
-        PYSONEncoder
-from trytond.pyson import Eval
 from trytond.pool import Pool
 
 
@@ -47,28 +42,28 @@ class InpatientRegistration(ModelSQL, ModelView):
     _name = 'gnuhealth.inpatient.registration'
     _description = __doc__
 
-    name = fields.Char('Registration Code', readonly=True, select="2")
+    name = fields.Char('Registration Code', readonly=True, select=True)
     patient = fields.Many2One('gnuhealth.patient', 'Patient',
-     required=True, select="1")
+     required=True, select=True)
     admission_type = fields.Selection([
         ('routine', 'Routine'),
         ('maternity', 'Maternity'),
         ('elective', 'Elective'),
         ('urgent', 'Urgent'),
         ('emergency', 'Emergency'),
-        ], 'Admission type', required=True, select="1")
+        ], 'Admission type', required=True, select=True)
     hospitalization_date = fields.DateTime('Hospitalization date',
-        required=True, select="1")
+        required=True, select=True)
     discharge_date = fields.DateTime('Discharge date', required=True,
-     select="1")
+     select=True)
     attending_physician = fields.Many2One('gnuhealth.physician',
-        'Attending Physician',select="2")
+        'Attending Physician',select=True)
     operating_physician = fields.Many2One('gnuhealth.physician',
         'Operating Physician')
     admission_reason = fields.Many2One('gnuhealth.pathology',
-        'Reason for Admission', help="Reason for Admission", select="1")
+        'Reason for Admission', help="Reason for Admission", select=True)
     bed = fields.Many2One('gnuhealth.hospital.bed', 'Hospital Bed',
-     required=True, select="2")
+     required=True, select=True)
     nursing_plan = fields.Text('Nursing Plan')
     discharge_plan = fields.Text('Discharge Plan')
 
@@ -78,7 +73,7 @@ class InpatientRegistration(ModelSQL, ModelView):
         ('cancelled', 'cancelled'),
         ('confirmed', 'confirmed'),
         ('hospitalized', 'hospitalized'),
-        ), 'Status', select="1")
+        ), 'Status', select=True)
 
 # Method to check for availability and make the hospital bed reservation
 
