@@ -1,25 +1,25 @@
-# coding=utf-8
-
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    GNU Health: The Free Health and Hospital Information System
 #    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
-
+#
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-
+#
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
-
+#
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-import StringIO
-from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
-from trytond.tools import safe_eval, datetime_strftime
+#
+##############################################################################
+from trytond.model import ModelView, ModelSQL, fields
 from trytond.transaction import Transaction
-from trytond.pyson import Eval
 from trytond.pool import Pool
 
 
